@@ -1,17 +1,17 @@
-/* This is based on Linux Wireless Extensions header file from WIRELESS_EXT 15.
+/* This is based on Linux Wireless Extensions header file from WIRELESS_EXT 18.
  * I have just removed kernel related headers and added some typedefs etc. to
  * make this easier to include into user space programs.
- * Jouni Malinen, 2002-12-21.
+ * Jouni Malinen, 2005-03-12.
  */
 
 
 /*
  * This file define a set of standard wireless extensions
  *
- * Version :	18	29.8.04
+ * Version :	18	12.3.05
  *
  * Authors :	Jean Tourrilhes - HPL - <jt@hpl.hp.com>
- * Copyright (c) 1997-2004 Jean Tourrilhes, All Rights Reserved.
+ * Copyright (c) 1997-2005 Jean Tourrilhes, All Rights Reserved.
  */
 
 #ifndef _LINUX_WIRELESS_H
@@ -211,11 +211,13 @@ typedef __uint8_t __u8;
  *	  SIOCGIWENCODEEXT)
  *	- Add SIOCSIWGENIE/SIOCGIWGENIE
  *	- Add SIOCSIWMLME
+ *	- Add SIOCSIWPMKSA
  *	- Add struct iw_range bit field for supported encoding capabilities
- *	- Add extended scan request (SIOCSIWSCANEXT)
+ *	- Add optional scan request parameters for SIOCSIWSCAN
  *	- Add SIOCSIWAUTH/SIOCGIWAUTH for setting authentication and WPA
  *	  related parameters (extensible up to 4096 parameter values)
- *	- Add wireless events: IWEVGENIE, IWEVMICHAELMICFAILURE
+ *	- Add wireless events: IWEVGENIE, IWEVMICHAELMICFAILURE,
+ *	  IWEVASSOCREQIE, IWEVASSOCRESPIE, IWEVPMKIDCAND
  */
 
 /**************************** CONSTANTS ****************************/
@@ -293,7 +295,10 @@ typedef __uint8_t __u8;
 /* WPA : Generic IEEE 802.11 informatiom element (e.g., for WPA/RSN/WMM).
  * This ioctl uses struct iw_point and data buffer that includes IE id and len
  * fields. More than one IE may be included in the request. Setting the generic
- * IE to empty buffer (len=0) removes the generic IE from the driver. */
+ * IE to empty buffer (len=0) removes the generic IE from the driver. Drivers
+ * are allowed to generate their own WPA/RSN IEs, but in these cases, drivers
+ * are required to report the used IE as a wireless event, e.g., when
+ * associating with an AP. */
 #define SIOCSIWGENIE	0x8B30		/* set generic IE */
 #define SIOCGIWGENIE	0x8B31		/* get generic IE */
 
@@ -308,10 +313,8 @@ typedef __uint8_t __u8;
 #define SIOCSIWENCODEEXT 0x8B34		/* set encoding token & mode */
 #define SIOCGIWENCODEEXT 0x8B35		/* get encoding token & mode */
 
-/* Extended scan request; like SIOCSIWSCAN, but with additional parameters in
- * struct iw_scan_req buffer. This shares SIOCGIWSCAN for reading the results.
- */
-#define SIOCSIWSCANEXT	0x8B36		/* trigger scanning (extended) */
+/* WPA2 : PMKSA cache management */
+#define SIOCSIWPMKSA	0x8B36		/* PMKSA cache operation */
 
 /* -------------------- DEV PRIVATE IOCTL LIST -------------------- */
 
@@ -363,6 +366,25 @@ typedef __uint8_t __u8;
 #define IWEVMICHAELMICFAILURE 0x8C06	/* Michael MIC failure
 					 * (struct iw_michaelmicfailure)
 					 */
+#define IWEVASSOCREQIE	0x8C07		/* IEs used in (Re)Association Request.
+					 * The data includes id and length
+					 * fields and may contain more than one
+					 * IE. This event is required in
+					 * Managed mode if the driver
+					 * generates its own WPA/RSN IE. This
+					 * should be sent just before
+					 * IWEVREGISTERED event for the
+					 * association. */
+#define IWEVASSOCRESPIE	0x8C08		/* IEs used in (Re)Association
+					 * Response. The data includes id and
+					 * length fields and may contain more
+					 * than one IE. This may be sent
+					 * between IWEVASSOCREQIE and
+					 * IWEVREGISTERED events for the
+					 * association. */
+#define IWEVPMKIDCAND	0x8C09		/* PMKID candidate for RSN
+					 * pre-authentication
+					 * (struct iw_pmkid_cand) */
 
 #define IWEVFIRST	0x8C00
 
@@ -530,6 +552,8 @@ typedef __uint8_t __u8;
 #define IW_AUTH_80211_AUTH_ALG		6
 #define IW_AUTH_WPA_ENABLED		7
 #define IW_AUTH_RX_UNENCRYPTED_EAPOL	8
+#define IW_AUTH_ROAMING_CONTROL		9
+#define IW_AUTH_PRIVACY_INVOKED		10
 
 /* IW_AUTH_WPA_VERSION values (bit field) */
 #define IW_AUTH_WPA_VERSION_DISABLED	0x00000001
@@ -552,6 +576,11 @@ typedef __uint8_t __u8;
 #define IW_AUTH_ALG_SHARED_KEY	0x00000002
 #define IW_AUTH_ALG_LEAP	0x00000004
 
+/* IW_AUTH_ROAMING_CONTROL values */
+#define IW_AUTH_ROAMING_ENABLE	0	/* driver/firmware based roaming */
+#define IW_AUTH_ROAMING_DISABLE	1	/* user space program used for roaming
+					 * control */
+
 /* SIOCSIWENCODEEXT definitions */
 #define IW_ENCODE_SEQ_MAX_SIZE	8
 /* struct iw_encode_ext ->alg */
@@ -688,27 +717,49 @@ struct	iw_thrspy
 };
 
 /*
- *	Data for extended scan request (MLME-SCAN.request)
+ *	Optional data for scan request
+ *
+ *	Note: these optional parameters are controlling parameters for the
+ *	scanning behavior, these do not apply to getting scan results
+ *	(SIOCGIWSCAN). Drivers are expected to keep a local BSS table and
+ *	provide a merged results with all BSSes even if the previous scan
+ *	request limited scanning to a subset, e.g., by specifying an SSID.
+ *	Especially, scan results are required to include an entry for the
+ *	current BSS if the driver is in Managed mode and associated with an AP.
  */
 struct	iw_scan_req
 {
-	__u8		mode;	/* IW_MODE_AUTO (= Both), IW_MODE_ADHOC, or
-				 * IW_MODE_INFRA */
 	__u8		scan_type; /* IW_SCAN_TYPE_{ACTIVE,PASSIVE} */
 	__u8		essid_len;
 	__u8		num_channels; /* num entries in channel_list;
 				       * 0 = scan all allowed channels */
+	__u8		flags; /* reserved as padding; use zero, this may
+				* be used in the future for adding flags
+				* to request different scan behavior */
 	struct sockaddr	bssid; /* ff:ff:ff:ff:ff:ff for broadcast BSSID or
 				* individual address of a specific BSS */
-	/* Use this ESSID if IW_SCAN_THIS_ESSID flag is used instead of using
+
+	/*
+	 * Use this ESSID if IW_SCAN_THIS_ESSID flag is used instead of using
 	 * the current ESSID. This allows scan requests for specific ESSID
 	 * without having to change the current ESSID and potentially breaking
-	 * the current association. */
+	 * the current association.
+	 */
 	__u8		essid[IW_ESSID_MAX_SIZE];
-	__u32		probe_delay; /* delay in usec prior to transmitting
-				      * ProbeReq */
-	__u32		min_channel_time; /* in TU, >= probe_delay */
-	__u32		max_channel_time; /* in TU, >= min_channel_time */
+
+	/*
+	 * Optional parameters for changing the default scanning behavior.
+	 * These are based on the MLME-SCAN.request from IEEE Std 802.11.
+	 * TU is 1.024 ms. If these are set to 0, driver is expected to use
+	 * reasonable default values. min_channel_time defines the time that
+	 * will be used to wait for the first reply on each channel. If no
+	 * replies are received, next channel will be scanned after this. If
+	 * replies are received, total time waited on the channel is defined by
+	 * max_channel_time.
+	 */
+	__u32		min_channel_time; /* in TU */
+	__u32		max_channel_time; /* in TU */
+
 	struct iw_freq	channel_list[IW_MAX_FREQUENCIES];
 };
 
@@ -759,6 +810,20 @@ struct	iw_mlme
 	struct sockaddr	addr;
 };
 
+/* SIOCSIWPMKSA data */
+#define IW_PMKSA_ADD		1
+#define IW_PMKSA_REMOVE		2
+#define IW_PMKSA_FLUSH		3
+
+#define IW_PMKID_LEN	16
+
+struct	iw_pmksa
+{
+	__u32		cmd; /* IW_PMKSA_* */
+	struct sockaddr	bssid;
+	__u8		pmkid[IW_PMKID_LEN];
+};
+
 /* IWEVMICHAELMICFAILURE data */
 struct	iw_michaelmicfailure
 {
@@ -767,6 +832,16 @@ struct	iw_michaelmicfailure
 	__u8		tsc[IW_ENCODE_SEQ_MAX_SIZE]; /* LSB first */
 };
 
+/* IWEVPMKIDCAND data */
+#define IW_PMKID_CAND_PREAUTH	0x00000001 /* RNS pre-authentication enabled */
+struct	iw_pmkid_cand
+{
+	__u32		flags; /* IW_PMKID_CAND_* */
+	__u32		index; /* the smaller the index, the higher the
+				* priority */
+	struct sockaddr	bssid;
+};
+
 /* ------------------------ WIRELESS STATS ------------------------ */
 /*
  * Wireless statistics (used for /proc/net/wireless)
